classpath-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[cp-patches] Patch: FYI: javadoc -vs- AWT


From: Tom Tromey
Subject: [cp-patches] Patch: FYI: javadoc -vs- AWT
Date: 03 Oct 2005 11:12:47 -0600
User-agent: Gnus/5.09 (Gnus v5.9.0) Emacs/21.3.50

I'm checking this in.

This fixes a number of javadoc buglets in AWT.  After this patch
eclipse reports just one remaining javadoc warning in AWT, and a few
serialization warnings.

Tom

2005-10-03  Tom Tromey  <address@hidden>

        * java/awt/Polygon.java (evaluateCrossings): Removed @see.
        * java/awt/image/ImageConsumer.java (SINGLEPASS): Javadoc fix.
        * java/awt/Image.java (getGraphics): Removed @see.
        * java/awt/MenuComponent.java (setEnabled): Javadoc fix.
        (setBackground): Likewise.
        * java/awt/event/MouseEvent.java: Added import for javadoc.
        * java/awt/im/spi/InputMethodDescriptor.java: Added import for javadoc.
        (getAvailableLocales): Javadoc fix.
        * java/awt/KeyboardFocusManager.java: Added import for javadoc.
        (defaultPolicy): Javadoc fix.
        (setGlobalObject): Javadoc fixes.
        (getObject): Likewise.
        (getGlobalObject): Likewise.
        * java/awt/im/InputMethodRequests.java: Added imports for javadoc.
        * java/awt/im/spi/InputMethodContext.java: Added imports for javadoc.
        (enableClientWindowNotification): Javadoc fix.
        * java/awt/im/spi/InputMethod.java: Added imports for javadoc.
        (removeNotify): Javadoc fix.
        (notifyClientWindowChange): Likewise.
        * java/awt/im/InputContext.java: Added import for javadoc.
        * java/awt/image/ColorModel.java (getDataElements): Javadoc fix.
        * java/awt/geom/Area.java (recursiveSubdivide): Javadoc fix.
        * java/awt/geom/GeneralPath.java (GeneralPathIterator): Javadoc fix.
        * java/awt/im/InputMethodHighlight.java: Javadoc fixes.  Added
        imports.
        * java/awt/color/ICC_Profile.java (getInstance): Javadoc fix.
        (getInstance): Likewise.
        * java/awt/EventQueue.java: Organized imports.
        * java/awt/image/BufferedImage.java: Organized imports.
        * java/awt/image/PackedColorModel.java (initMasks): Javadoc fix.
        * java/awt/GraphicsConfiguration.java (createCompatibleVolatileImage):
        Javadoc fixes.
        * java/awt/DefaultKeyboardFocusManager.java (delayRequests): Javadoc
        fix.
        * java/awt/ColorPaintContext.java (ColorPaintContext): Javadoc fix.

Index: java/awt/ColorPaintContext.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/ColorPaintContext.java,v
retrieving revision 1.5
diff -u -r1.5 ColorPaintContext.java
--- java/awt/ColorPaintContext.java     6 Jul 2005 08:15:16 -0000       1.5
+++ java/awt/ColorPaintContext.java     3 Oct 2005 15:18:21 -0000
@@ -63,7 +63,7 @@
   /**
    * Create the context for a given color.
    *
-   * @param c The solid color to use.
+   * @param colorRGB The solid color to use.
    */
   ColorPaintContext(int colorRGB)
   {
@@ -74,7 +74,7 @@
    * Create the context for a given color.
    *
    * @param cm The color model of this context. 
-   * @param c The solid color to use.
+   * @param colorRGB The solid color to use.
    */
   ColorPaintContext(ColorModel cm,int colorRGB)
   {
Index: java/awt/DefaultKeyboardFocusManager.java
===================================================================
RCS file: 
/cvsroot/classpath/classpath/java/awt/DefaultKeyboardFocusManager.java,v
retrieving revision 1.15
diff -u -r1.15 DefaultKeyboardFocusManager.java
--- java/awt/DefaultKeyboardFocusManager.java   5 Jul 2005 19:16:00 -0000       
1.15
+++ java/awt/DefaultKeyboardFocusManager.java   3 Oct 2005 15:18:21 -0000
@@ -146,8 +146,8 @@
    */
   private AWTKeyStroke waitForKeyStroke = null;
 
-  /** The address@hidden java.util.SortedSet} of current address@hidden
-      #EventDelayRequest}s. */
+  /** The address@hidden java.util.SortedSet} of current 
+   * address@hidden EventDelayRequest}s. */
   private SortedSet delayRequests = new TreeSet ();
 
   public DefaultKeyboardFocusManager ()
Index: java/awt/EventQueue.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/EventQueue.java,v
retrieving revision 1.25
diff -u -r1.25 EventQueue.java
--- java/awt/EventQueue.java    23 Aug 2005 05:27:06 -0000      1.25
+++ java/awt/EventQueue.java    3 Oct 2005 15:18:21 -0000
@@ -42,7 +42,6 @@
 import java.awt.event.InputEvent;
 import java.awt.event.InputMethodEvent;
 import java.awt.event.InvocationEvent;
-import java.awt.event.WindowEvent;
 import java.lang.reflect.InvocationTargetException;
 import java.util.EmptyStackException;
 
Index: java/awt/GraphicsConfiguration.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/GraphicsConfiguration.java,v
retrieving revision 1.7
diff -u -r1.7 GraphicsConfiguration.java
--- java/awt/GraphicsConfiguration.java 19 Aug 2005 01:29:26 -0000      1.7
+++ java/awt/GraphicsConfiguration.java 3 Oct 2005 15:18:21 -0000
@@ -130,11 +130,10 @@
    * with the given transparency. Because the buffer is volatile, it
    * can be optimized by native graphics accelerators.
    *
-   * @param w the width of the buffer
-   * @param h the height of the buffer
+   * @param width the width of the buffer
+   * @param height the height of the buffer
    * @param transparency the transparency value for the buffer
    * @return the buffered image, or null if none is supported
-   * @throws AWTException if the capabilities cannot be met
    * @since 1.5
    */
   public abstract VolatileImage createCompatibleVolatileImage(int width,
Index: java/awt/Image.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/Image.java,v
retrieving revision 1.11
diff -u -r1.11 Image.java
--- java/awt/Image.java 6 Jul 2005 08:15:17 -0000       1.11
+++ java/awt/Image.java 3 Oct 2005 15:18:21 -0000
@@ -141,7 +141,6 @@
    * This method is only valid for off-screen objects.
    *
    * @return a graphics context object for an off-screen object
-   * @see Graphics#getcreateImage(int, int)
    */
   public abstract Graphics getGraphics();
 
Index: java/awt/MenuComponent.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/MenuComponent.java,v
retrieving revision 1.22
diff -u -r1.22 MenuComponent.java
--- java/awt/MenuComponent.java 2 Jul 2005 20:32:25 -0000       1.22
+++ java/awt/MenuComponent.java 3 Oct 2005 15:18:22 -0000
@@ -1157,7 +1157,7 @@
    * the appropriate information.
    *
    * @param color the new color to use for the background.
-   * @see getBackground()
+   * @see #getBackground()
    */
   public void setBackground(Color color)
   {
@@ -1217,7 +1217,7 @@
    *
    * @param enabled true if the component should be enabled,
    *        false otherwise.
-   * @see #getEnabled()
+   * @see #isEnabled()
    */
   public void setEnabled(boolean enabled)
   {
Index: java/awt/Polygon.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/Polygon.java,v
retrieving revision 1.13
diff -u -r1.13 Polygon.java
--- java/awt/Polygon.java       2 Jul 2005 20:32:25 -0000       1.13
+++ java/awt/Polygon.java       3 Oct 2005 15:18:22 -0000
@@ -544,7 +544,6 @@
    * the positive X, or Y axis, within a given interval.
    *
    * @return the winding number.
-   * @see #condensed
    * @see #contains(double, double)
    */
   private int evaluateCrossings(double x, double y, boolean useYaxis,
Index: java/awt/color/ICC_Profile.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/color/ICC_Profile.java,v
retrieving revision 1.12
diff -u -r1.12 ICC_Profile.java
--- java/awt/color/ICC_Profile.java     2 Jul 2005 20:32:26 -0000       1.12
+++ java/awt/color/ICC_Profile.java     3 Oct 2005 15:18:22 -0000
@@ -324,11 +324,11 @@
    * An instance of the specialized classes ICC_ProfileRGB or ICC_ProfileGray
    * may be returned if appropriate.
    *
-   * @throws IllegalArgumentException if the profile data is an invalid
-   * v2 profile.
-   *
    * @param data - the profile data
    * @return An ICC_Profile object
+   *
+   * @throws IllegalArgumentException if the profile data is an invalid
+   * v2 profile.
    */
   public static ICC_Profile getInstance(byte[] data)
   {
@@ -373,12 +373,12 @@
    * An instance of the specialized classes ICC_ProfileRGB or ICC_ProfileGray
    * may be returned if appropriate.
    *
+   * @param filename - the file name of the profile file.
+   * @return An ICC_Profile object
+   *
    * @throws IllegalArgumentException if the profile data is an invalid
    * v2 profile.
    * @throws IOException if the file could not be read.
-   *
-   * @param filename - the file name of the profile file.
-   * @return An ICC_Profile object
    */
   public static ICC_Profile getInstance(String filename)
                                  throws IOException
@@ -400,12 +400,12 @@
    * An instance of the specialized classes ICC_ProfileRGB or ICC_ProfileGray
    * may be returned if appropriate.
    *
+   * @param in - the input stream to read the profile from.
+   * @return An ICC_Profile object
+   *
    * @throws IllegalArgumentException if the profile data is an invalid
    * v2 profile.
    * @throws IOException if the stream could not be read.
-   *
-   * @param in - the input stream to read the profile from.
-   * @return An ICC_Profile object
    */
   public static ICC_Profile getInstance(InputStream in)
                                  throws IOException
Index: java/awt/event/MouseEvent.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/event/MouseEvent.java,v
retrieving revision 1.11
diff -u -r1.11 MouseEvent.java
--- java/awt/event/MouseEvent.java      12 Sep 2005 03:46:42 -0000      1.11
+++ java/awt/event/MouseEvent.java      3 Oct 2005 15:18:23 -0000
@@ -42,6 +42,7 @@
 
 import java.awt.Component;
 import java.awt.Point;
+import java.awt.PopupMenu;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 
Index: java/awt/geom/Area.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/geom/Area.java,v
retrieving revision 1.8
diff -u -r1.8 Area.java
--- java/awt/geom/Area.java     2 Jul 2005 20:32:29 -0000       1.8
+++ java/awt/geom/Area.java     3 Oct 2005 15:18:23 -0000
@@ -1215,7 +1215,7 @@
    * @param t1 - global parametric value of the first curve's starting point
    * @param t2 - global parametric value of the second curve's starting point
    * @param w1 - global parametric length of curve 1
-   * @param c1 - global parametric length of curve 2
+   * @param w2 - global parametric length of curve 2
    *
    * The final four parameters are for keeping track of the parametric
    * value of the curve. For a full curve t = 0, w = 1, w is halved with
Index: java/awt/geom/GeneralPath.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/geom/GeneralPath.java,v
retrieving revision 1.13
diff -u -r1.13 GeneralPath.java
--- java/awt/geom/GeneralPath.java      2 Jul 2005 20:32:29 -0000       1.13
+++ java/awt/geom/GeneralPath.java      3 Oct 2005 15:18:23 -0000
@@ -558,7 +558,8 @@
      * Constructs a new iterator for enumerating the segments of a
      * GeneralPath.
      *
-     * @param at an affine transformation for projecting the returned
+     * @param path the path to enumerate
+     * @param transform an affine transformation for projecting the returned
      * points, or <code>null</code> to return the original points
      * without any mapping.
      */
Index: java/awt/im/InputContext.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/im/InputContext.java,v
retrieving revision 1.9
diff -u -r1.9 InputContext.java
--- java/awt/im/InputContext.java       2 Jul 2005 20:32:29 -0000       1.9
+++ java/awt/im/InputContext.java       3 Oct 2005 15:18:25 -0000
@@ -49,6 +49,7 @@
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.net.URL;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -334,7 +335,7 @@
 
   /**
    * Starts a reconversion operation in the current input method. The input
-   * method gets theh text to reconvert from the client component, using
+   * method gets the text to reconvert from the client component, using
    * address@hidden InputMethodRequests#getSelectedText(Attribute[])}. Then the
    * composed and committed text produced by the operation is sent back to
    * the client using a sequence of InputMethodRequests.
Index: java/awt/im/InputMethodHighlight.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/im/InputMethodHighlight.java,v
retrieving revision 1.4
diff -u -r1.4 InputMethodHighlight.java
--- java/awt/im/InputMethodHighlight.java       2 Jul 2005 20:32:29 -0000       
1.4
+++ java/awt/im/InputMethodHighlight.java       3 Oct 2005 15:18:25 -0000
@@ -37,6 +37,9 @@
 
 package java.awt.im;
 
+import java.awt.Toolkit;
+import java.text.Annotation;
+import java.text.AttributedCharacterIterator;
 import java.util.Map;
 
 /**
@@ -53,7 +56,7 @@
  * text segments.
  *
  * @author Eric Blake (address@hidden)
- * @see AttributedCharacterIterators
+ * @see AttributedCharacterIterator
  * @see Annotation
  * @since 1.2
  * @status updated to 1.4
Index: java/awt/im/InputMethodRequests.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/im/InputMethodRequests.java,v
retrieving revision 1.3
diff -u -r1.3 InputMethodRequests.java
--- java/awt/im/InputMethodRequests.java        2 Jul 2005 20:32:29 -0000       
1.3
+++ java/awt/im/InputMethodRequests.java        3 Oct 2005 15:18:25 -0000
@@ -37,8 +37,10 @@
 
 package java.awt.im;
 
+import java.awt.Component;
 import java.awt.Rectangle;
 import java.awt.font.TextHitInfo;
+import java.awt.event.InputMethodListener;
 import java.text.AttributedCharacterIterator;
 import java.text.AttributedCharacterIterator.Attribute;
 
Index: java/awt/im/spi/InputMethod.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/im/spi/InputMethod.java,v
retrieving revision 1.4
diff -u -r1.4 InputMethod.java
--- java/awt/im/spi/InputMethod.java    2 Jul 2005 20:32:29 -0000       1.4
+++ java/awt/im/spi/InputMethod.java    3 Oct 2005 15:18:25 -0000
@@ -38,7 +38,11 @@
 package java.awt.im.spi;
 
 import java.awt.AWTEvent;
+import java.awt.Component;
 import java.awt.Rectangle;
+import java.awt.im.InputContext;
+import java.awt.im.InputMethodRequests;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.util.Locale;
 
 /**
@@ -152,8 +156,8 @@
    * Notify this input method of changes in the client window. This is called
    * when notifications are enabled (see address@hidden
    * InputMethodContext#enableClientWindowNotification(InputMethod, boolean)},
-   * if address@hidden #removeNotify(Component)} has not been called. The 
following
-   * situations trigger a notification:<ul>
+   * if address@hidden InputContext#removeNotify(Component)} has not been 
called.
+   * The following situations trigger a notification:<ul>
    * <li>The client window changes in location, size, visibility,
    * iconification, or is closed.</li>
    * <li>When enabling client notification (or on the first activation after
@@ -202,7 +206,7 @@
   /**
    * Notify the input method that a client component has been removed from its
    * hierarchy, or that input method support has been disabled. This is
-   * called by address@hidden InputContext#removeNotify()}, and only when the 
input
+   * called by address@hidden InputContext#removeNotify(Component)}, and only 
when the input
    * method is inactive.
    */
   void removeNotify();
Index: java/awt/im/spi/InputMethodContext.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/im/spi/InputMethodContext.java,v
retrieving revision 1.4
diff -u -r1.4 InputMethodContext.java
--- java/awt/im/spi/InputMethodContext.java     2 Jul 2005 20:32:29 -0000       
1.4
+++ java/awt/im/spi/InputMethodContext.java     3 Oct 2005 15:18:25 -0000
@@ -38,6 +38,8 @@
 
 package java.awt.im.spi;
 
+import java.awt.HeadlessException;
+import java.awt.Rectangle;
 import java.awt.Window;
 import java.awt.font.TextHitInfo;
 import java.awt.im.InputMethodRequests;
@@ -113,7 +115,7 @@
   /**
    * Sets whether notification of the client window's location and state should
    * be enabled for the input method. When enabled, the input method's
-   * address@hidden #notifyClientWindowChange(Rectangle)} method is called.
+   * address@hidden InputMethod#notifyClientWindowChange(Rectangle)} method is 
called.
    * Notification is automatically disabled when the input method is disposed.
    *
    * @param inputMethod the method to change status of
Index: java/awt/im/spi/InputMethodDescriptor.java
===================================================================
RCS file: 
/cvsroot/classpath/classpath/java/awt/im/spi/InputMethodDescriptor.java,v
retrieving revision 1.4
diff -u -r1.4 InputMethodDescriptor.java
--- java/awt/im/spi/InputMethodDescriptor.java  2 Jul 2005 20:32:29 -0000       
1.4
+++ java/awt/im/spi/InputMethodDescriptor.java  3 Oct 2005 15:18:25 -0000
@@ -39,6 +39,7 @@
 
 import java.awt.AWTException;
 import java.awt.Image;
+import java.awt.im.InputContext;
 import java.util.Locale;
 
 /**
@@ -57,7 +58,7 @@
    * also by country and variant), via
    * address@hidden InputContext#selectInputMethod(Locale)}. The returned list 
should
    * ignore pass-through locales, so it is usually a subset of locales for
-   * which address@hidden InputMethod#setContext(Locale)} returns true. If
+   * which address@hidden InputMethod#setLocale(Locale)} returns true. If
    * address@hidden #hasDynamicLocaleList()} returns true, this is called each 
time
    * information is needed, allowing dynamic addition or removal of supported
    * locales.
Index: java/awt/image/BufferedImage.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/image/BufferedImage.java,v
retrieving revision 1.11
diff -u -r1.11 BufferedImage.java
--- java/awt/image/BufferedImage.java   2 Jul 2005 20:32:30 -0000       1.11
+++ java/awt/image/BufferedImage.java   3 Oct 2005 15:18:25 -0000
@@ -48,9 +48,7 @@
 import java.awt.Rectangle;
 import java.awt.Transparency;
 import java.awt.color.ColorSpace;
-import java.util.HashSet;
 import java.util.Hashtable;
-import java.util.Iterator;
 import java.util.Vector;
 
 /**
Index: java/awt/image/ColorModel.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/image/ColorModel.java,v
retrieving revision 1.25
diff -u -r1.25 ColorModel.java
--- java/awt/image/ColorModel.java      2 Jul 2005 20:32:30 -0000       1.25
+++ java/awt/image/ColorModel.java      3 Oct 2005 15:18:25 -0000
@@ -609,7 +609,7 @@
    * @param obj Array of TransferType or null.
    *
    * @return pixel value encoded according to the color model.
-   * @throws ArrayIndexOutOfBounds
+   * @throws ArrayIndexOutOfBoundsException
    * @throws ClassCastException
    * @since 1.4
    */
Index: java/awt/image/ImageConsumer.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/image/ImageConsumer.java,v
retrieving revision 1.8
diff -u -r1.8 ImageConsumer.java
--- java/awt/image/ImageConsumer.java   2 Jul 2005 20:32:34 -0000       1.8
+++ java/awt/image/ImageConsumer.java   3 Oct 2005 15:18:25 -0000
@@ -75,7 +75,7 @@
      * most one call to <code>setPixels</code> for any single pixel.
      *
      * @see #setHints
-     * @see #setPixels 
+     * @see #setPixels(int, int, int, int, ColorModel, int[], int, int) 
      */
     int SINGLEPASS = 8;
 
Index: java/awt/KeyboardFocusManager.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/KeyboardFocusManager.java,v
retrieving revision 1.15
diff -u -r1.15 KeyboardFocusManager.java
--- java/awt/KeyboardFocusManager.java  7 Jul 2005 12:37:04 -0000       1.15
+++ java/awt/KeyboardFocusManager.java  3 Oct 2005 15:18:22 -0000
@@ -39,6 +39,7 @@
 package java.awt;
 
 import java.applet.Applet;
+import java.awt.FocusTraversalPolicy;
 import java.awt.event.FocusEvent;
 import java.awt.event.KeyEvent;
 import java.awt.event.WindowEvent;
@@ -213,7 +214,7 @@
       currentFocusOwners */
   private static Map currentFocusCycleRoots = new HashMap ();
 
   /** The default address@hidden FocusTraveralPolicy} that focus-managing
       address@hidden Container}s will use to define their initial focus
       traversal policy. */
   private FocusTraversalPolicy defaultPolicy;
@@ -1364,11 +1365,11 @@
    *
    * @return a global object set by the current ThreadGroup, or null
    *
-   * @see getFocusOwner
-   * @see getPermanentFocusOwner
-   * @see getFocusedWindow
-   * @see getActiveWindow
-   * @see getCurrentFocusCycleRoot
+   * @see #getFocusOwner()
+   * @see #getPermanentFocusOwner()
+   * @see #getFocusedWindow()
+   * @see #getActiveWindow()
+   * @see #getCurrentFocusCycleRoot()
    */
   private Object getObject (Map globalMap)
   {
@@ -1388,11 +1389,11 @@
    * @throws SecurityException if this is not the keyboard focus
    * manager associated with the current address@hidden java.lang.ThreadGroup}
    *
-   * @see getGlobalFocusOwner
-   * @see getGlobalPermanentFocusOwner
-   * @see getGlobalFocusedWindow
-   * @see getGlobalActiveWindow
-   * @see getGlobalCurrentFocusCycleRoot
+   * @see #getGlobalFocusOwner()
+   * @see #getGlobalPermanentFocusOwner()
+   * @see #getGlobalFocusedWindow()
+   * @see #getGlobalActiveWindow()
+   * @see #getGlobalCurrentFocusCycleRoot()
    */
   private Object getGlobalObject (Map globalMap)
   {
@@ -1432,11 +1433,11 @@
    * @param newObject the object to set
    * @param property the property that will change
    *
-   * @see setGlobalFocusOwner
-   * @see setGlobalPermanentFocusOwner
-   * @see setGlobalFocusedWindow
-   * @see setGlobalActiveWindow
-   * @see setGlobalCurrentFocusCycleRoot
+   * @see #setGlobalFocusOwner(Component)
+   * @see #setGlobalPermanentFocusOwner(Component)
+   * @see #setGlobalFocusedWindow(Window)
+   * @see #setGlobalActiveWindow(Window)
+   * @see #setGlobalCurrentFocusCycleRoot(Container)
    */
   private void setGlobalObject (Map globalMap,
                                 Object newObject,
@@ -213,7 +214,7 @@
   private static Map currentFocusCycleRoots = new HashMap ();
 
-  /** The default address@hidden FocusTraveralPolicy} that focus-managing
+  /** The default address@hidden FocusTraversalPolicy} that focus-managing
       address@hidden Container}s will use to define their initial focus
       traversal policy. */
Index: java/awt/image/PackedColorModel.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/image/PackedColorModel.java,v
retrieving revision 1.5
diff -u -r1.5 PackedColorModel.java
--- java/awt/image/PackedColorModel.java        2 Jul 2005 20:32:36 -0000       
1.5
+++ java/awt/image/PackedColorModel.java        3 Oct 2005 15:18:25 -0000
@@ -90,11 +90,7 @@
     return bitsPerComponent;
   }
 
-  /** Initializes the masks.
-   *
-   * @return an array containing the number of bits per color
-   * component.
-   */
+  /** Initializes the masks.  */
   private void initMasks(int[] colorMaskArray, int alphaMask)
   {
     int numComponents = colorMaskArray.length;




reply via email to

[Prev in Thread] Current Thread [Next in Thread]